@@ -3,6 +3,7 @@ import numpy as np
 from numpy.fft import fft,ifft
 import matplotlib.pyplot as plt
 import pywt
+import scipy
 import scipy.signal
 from scipy import signal
 from Audio_proc_lib.audio_proc_functions import *
@@ -52,7 +53,7 @@ def plot_frequency_and_angle_response(impulse_resp):
 
     ax2.axis('tight')
 
-    plt.show()
+
 
 def plot_response(fs, w, h, title):
 
@@ -84,7 +85,7 @@ def plot_spectrogram(X,sr,y_scale="log"):
     plt.colorbar(format='%+2.0f dB')
     #plt.title('Constant-Q power spectrum')
     plt.tight_layout()
-    plt.show()
+
 
 def plot_cqt_custom(X,B=12,ksi_min=32.7):
     fig, ax = plt.subplots(1,1)
@@ -102,7 +103,7 @@ def plot_cqt_custom(X,B=12,ksi_min=32.7):
     ax.set_yticklabels(y_label_list)
 
     fig.colorbar(img)
-    plt.show()
+
 
 
 
@@ -140,7 +141,7 @@ def plot_spectrogram_pseudo_RT(X):
         fig.canvas.draw()
         fig.canvas.flush_events()
 
-    plt.show()
+
 
 
 def plot_cqt_pseudo_RT(X,B,ksi_min):
@@ -185,7 +186,7 @@ def plot_cqt_pseudo_RT(X,B,ksi_min):
         fig.canvas.draw()
         fig.canvas.flush_events()
 
-    plt.show()
+
 
         
 
@@ -231,7 +232,7 @@ def plot_magnitude_fft(yf,db,s,full=False):
 
     # plt.tick_params(axis='x', which='minor')
     # ax.xaxis.set_minor_formatter(FormatStrFormatter("%.1f"))
-    plt.show()
+
 
 
 
@@ -259,7 +260,68 @@ def plot_cqt(signal,c):
     pmax = np.percentile(grid, 99.99)
     plt.imshow(grid, aspect='auto', origin='lower', vmin=pmax-80, vmax=pmax)
     plt.colorbar()
-    plt.show()
+
+
+def plot_TF_transform(c,transform,matrix_form,sr):
+
+    if transform=="SCALE_FRAMES":
+
+      if not(matrix_form):
+        from scipy import interpolate
+        c_matrix = []
+        max_win_len = np.array( list( map( lambda x : len(x) , c ) ) ).max()
+        for n in range(len(c)):
+            N = len(c[n])
+            fk = np.arange(N)*(22050/N)
+            (x,y) = (fk,np.abs(c[n]))
+
+            f = interpolate.interp1d(x, y)
+
+            xnew = np.linspace(0, fk[N-1], max_win_len)
+            ynew = f(xnew)
+            c_matrix.append( ynew )  
+
+
+        grid = np.array(c_matrix).T
+        np.log10(grid, out=grid)
+        grid *= 20
+        pmax = np.percentile(grid, 99.99)
+        plt.imshow(grid, cmap="inferno" ,aspect='auto', origin='lower', vmin=pmax-80, vmax=pmax,extent=[0,200,0,22050])
+
+        plt.ylim(bottom=100)
+
+        plt.yscale("log")
+
+        loc = np.array([  100.,  1000., 10000.,22050.])
+        labels = [ plt.Text(100.0, 0, '$\\mathdefault{100}$') , plt.Text(1000.0, 0, '$\\mathdefault{1000}$') , plt.Text(10000.0, 0, '$\\mathdefault{10000}$'), plt.Text(22050.0, 0, '$\\mathdefault{22050}$')  ]
+        plt.yticks(loc,labels)    
+
+        plt.ylim(top=22050)
+
+
+        plt.colorbar()
+        plt.ylabel("Hz (log scale)")
+
+      else:
+        plot_spectrogram(np.array(c).T,44100,"log")
+
+
+
+    if transform=="NSGT_CQT":
+
+      if not(matrix_form):
+        plot_cqt(x,c)
+      else:
+        plot_spectrogram(c,44100,"cqt_notes")
+
+    if transform=="STFT_custom":
+      librosa.display.specshow(librosa.amplitude_to_db(np.abs(c), ref=np.max),
+                    sr=sr, x_axis='time', y_axis="log")
+      plt.colorbar(format='%+2.0f dB')
+      #plt.title('Constant-Q power spectrum')
+      plt.tight_layout()
+
+
 
 #DCT4 transform-----------------------
 def DCT4(samples):
